GPayParams class

A class representing Google Pay configurations.

Constructors

GPayParams({GPayButtonType? buttonType, GPayButtonStyle? buttonStyle})
GPayParams.fromJson(Map<String, dynamic> json)
Factory method to create a GPayParams from a JSON map.
factory

Properties

buttonStyle ↔ GPayButtonStyle?
getter/setter pair
buttonType ↔ GPayButtonType?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this GPayParams instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited